@@ -284,7 +284,7 @@ uint32_t
 CacheDigest::CalcMaskSize(uint64_t cap, uint8_t bpe)
 {
     uint64_t bitCount = (cap * bpe) + 7;
-    assert(bitCount < INT_MAX); // dont 31-bit overflow later
+    assert(bitCount < INT_MAX); // do not 31-bit overflow later
     return static_cast<uint32_t>(bitCount / 8);
 }
 
