@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2018 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -10,33 +10,29 @@
 #define SQUID_ACLNOTEDATA_H
 
 #include "acl/Data.h"
-#include "MemPool.h"
+#include "Notes.h"
 #include "SquidString.h"
 
-class HttpRequest;
-class NotePairs;
+class ACLStringData;
 
 /// \ingroup ACLAPI
-class ACLNoteData : public ACLData<HttpRequest *>
+class ACLNoteData : public ACLData<NotePairs::Entry *>
 {
-public:
     MEMPROXY_CLASS(ACLNoteData);
 
+public:
     ACLNoteData();
     virtual ~ACLNoteData();
-    virtual bool match(HttpRequest* request);
+    virtual bool match(NotePairs::Entry *);
     virtual SBufList dump() const;
     virtual void parse();
     virtual bool empty() const;
-    virtual ACLData<HttpRequest *> *clone() const;
+    virtual ACLData<NotePairs::Entry *> *clone() const;
 
 private:
-    bool matchNotes(NotePairs *note);
     String name;                   ///< Note name to check. It is always set
-    ACLData<char const *> *values; ///< if set, at least one value must match
+    ACLStringData *values; ///< if set, at least one value must match
 };
 
-MEMPROXY_CLASS_INLINE(ACLNoteData);
-
 #endif /* SQUID_ACLNOTEDATA_H */
 
