@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2016 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2018 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -14,7 +14,7 @@
 #if USE_ICMP
 
 #include "cache_cf.h"
-#include "SBuf.h"
+#include "sbuf/SBuf.h"
 
 /**
  * Squid pinger Configuration settings
